# Generate Files

This package includes Generate Files class having 
various functions to generate CSV , PDF , HTML , XLSX , XML Files
from the fetched API data. You can use
[generate_files](https://github.com/Mohammad-Toseef/Week1.git)
to contribute to the package.